@@ -57,6 +57,8 @@ elif dpkg-architecture -iany-arm64; then
 	OPT=jit
 elif dpkg-architecture -iany-ppc64el || dpkg-architecture -iany-ppc64; then
 	OPT=jit
+elif dpkg-architecture -iany-riscv64; then
+	OPT=jit
 elif dpkg-architecture -iany-s390x; then
 	OPT=jit
 fi
@@ -74,6 +76,7 @@ if dpkg-architecture -iany-i386 \
    || dpkg-architecture -iany-mips64el \
    || dpkg-architecture -iany-ppc64 \
    || dpkg-architecture -iany-ppc64el \
+   || dpkg-architecture -iany-riscv64 \
    || dpkg-architecture -iany-s390x; then
 	CONTINUATION=1
 fi
@@ -131,4 +134,4 @@ cd "$CURDIR"
 # memory and avoid timeouts:
 make -C $C_SRC_DIR $SUB_MAKEFLAGS
 
-cp $C_SRC_DIR/pypy3-c $C_SRC_DIR/libpypy3-c.so pypy/goal
+cp $C_SRC_DIR/pypy3.11-c $C_SRC_DIR/libpypy3.11-c.so pypy/goal
